# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKFastMarchingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkFastMarchingStoppingCriterionBasePython
else:
    import _itkFastMarchingStoppingCriterionBasePython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkNodePairPython
class itkFastMarchingStoppingCriterionBaseIF2IF2(itk.ITKCommonBasePython.itkStoppingCriterionBase):
    r"""Proxy of C++ itkFastMarchingStoppingCriterionBaseIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def Reinitialize(self):
        r"""Reinitialize(self)"""
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF2IF2_Reinitialize(self)

    def SetCurrentNodePair(self, iNodePair):
        r"""
        SetCurrentNodePair(self, iNodePair)

        Parameters
        ----------
        iNodePair: itkNodePairI2F const &

        """
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF2IF2_SetCurrentNodePair(self, iNodePair)

    def SetDomain(self, _arg):
        r"""
        SetDomain(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 *

        """
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF2IF2_SetDomain(self, _arg)

    def GetModifiableDomain(self):
        r"""GetModifiableDomain(self) -> itkImageF2"""
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF2IF2_GetModifiableDomain(self)

    def GetDomain(self, *args):
        r"""
        GetDomain(self) -> itkImageF2
        GetDomain(self) -> itkImageF2
        """
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF2IF2_GetDomain(self, *args)
    __swig_destroy__ = _itkFastMarchingStoppingCriterionBasePython.delete_itkFastMarchingStoppingCriterionBaseIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingStoppingCriterionBaseIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF2IF2_cast(obj)

# Register itkFastMarchingStoppingCriterionBaseIF2IF2 in _itkFastMarchingStoppingCriterionBasePython:
_itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF2IF2_swigregister(itkFastMarchingStoppingCriterionBaseIF2IF2)
class itkFastMarchingStoppingCriterionBaseIF3IF3(itk.ITKCommonBasePython.itkStoppingCriterionBase):
    r"""Proxy of C++ itkFastMarchingStoppingCriterionBaseIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def Reinitialize(self):
        r"""Reinitialize(self)"""
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF3IF3_Reinitialize(self)

    def SetCurrentNodePair(self, iNodePair):
        r"""
        SetCurrentNodePair(self, iNodePair)

        Parameters
        ----------
        iNodePair: itkNodePairI3F const &

        """
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF3IF3_SetCurrentNodePair(self, iNodePair)

    def SetDomain(self, _arg):
        r"""
        SetDomain(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 *

        """
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF3IF3_SetDomain(self, _arg)

    def GetModifiableDomain(self):
        r"""GetModifiableDomain(self) -> itkImageF3"""
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF3IF3_GetModifiableDomain(self)

    def GetDomain(self, *args):
        r"""
        GetDomain(self) -> itkImageF3
        GetDomain(self) -> itkImageF3
        """
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF3IF3_GetDomain(self, *args)
    __swig_destroy__ = _itkFastMarchingStoppingCriterionBasePython.delete_itkFastMarchingStoppingCriterionBaseIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingStoppingCriterionBaseIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF3IF3_cast(obj)

# Register itkFastMarchingStoppingCriterionBaseIF3IF3 in _itkFastMarchingStoppingCriterionBasePython:
_itkFastMarchingStoppingCriterionBasePython.itkFastMarchingStoppingCriterionBaseIF3IF3_swigregister(itkFastMarchingStoppingCriterionBaseIF3IF3)

